output

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 16, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CopyToClipboard

func CopyToClipboard(content string) error

CopyToClipboard copies the content to the system clipboard

func ResolveOutputPath

func ResolveOutputPath(outputFlag string, title string) (string, error)

ResolveOutputPath determines the final output path If path is a directory, generates filename from title If path is a file, uses it directly

func WriteToFile

func WriteToFile(path string, content string) error

WriteToFile writes content to the specified path

Types

This section is empty.

Jump to