Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CopyToClipboard ¶
CopyToClipboard copies the content to the system clipboard
func ResolveOutputPath ¶
ResolveOutputPath determines the final output path If path is a directory, generates filename from title If path is a file, uses it directly
func WriteToFile ¶
WriteToFile writes content to the specified path
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.